@@ -1,5 +1,5 @@
 /*  Motti -- a strategy game
-    Copyright (C) 1999-2010 Free Software Foundation
+    Copyright (C) 1999-2014 Free Software Foundation
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include "Serializer.h"
 #include "AiPlayer.h"
 #include "MapGenerator.h"
+#include "MottiRulesManager.h"
 
 #if defined __CYGWIN32__ 
 #include <dirent.h>
@@ -814,9 +815,15 @@ void GameManager::transitionMapPlayers(){
 		meesBox_->setMessage(message.str());
 		drawer_->draw(meesBox_);
 		//void (*writesmessage)(std::string title,std::string message) ;
+		std::list <std::string> list;
 		
-		
-		Case *pp=mm.generateMap(playersGen,xsizeGen,ysizeGen);
+		for (int i=0;i<playersGen;i++)
+		{
+		  std::stringstream name;
+		  name<<"P"<<i;
+		  list.push_back(name.str());
+		}
+		Case *pp=mm.generateMap(list,xsizeGen,ysizeGen);
 		board_->setCases(pp);
 		playersGen=0;
 		board_->setWidth(xsizeGen);
@@ -1545,4 +1552,189 @@ std::vector<std::string> GameManager::listDir(std::string direrc){
 
 	  return list;
 }
+#include "JSONParser.h"
+#include "MapGenerator.h"
+#include <stdlib.h> 
 
+#include "GamePersistanceService.h"
+#include "SessionService.h"
+#include <sstream>
+std::string CreateGame::internalDispatch(std::string msg,std::string session){
+	std::istringstream  ssJson(msg);
+  json_parser::Parser parser(&ssJson);
+  try{
+    json_parser::Value *val = parser.jValue();
+    
+    json_parser::Object* my_object = dynamic_cast<json_parser::Object*>(val);
+    if (my_object==NULL)
+      return "Error casting object";
+    json_parser::Value *width=getValue(my_object,"width");
+    json_parser::Value *heigth=getValue(my_object,"heigth");
+    json_parser::Value *nbPlayer=getValue(my_object,"nbPlayer");
+    json_parser::Value *nbComputer=getValue(my_object,"nbComputer");
+    int widthnum = atoi(width->cleanStr().c_str());
+    int heigthnum = atoi(heigth->cleanStr().c_str());
+    int nbPlayernum = atoi(nbPlayer->cleanStr().c_str());
+    int nbComputernum = atoi(nbComputer->cleanStr().c_str());
+    Board board(widthnum,heigthnum);
+    
+    
+    
+    std::string user=SessionService::retrieveUserFromSession(session);
+    std::string gameid=GamePersistanceService::create(user);
+    /*if(nbPlayernum!=nbComputernum)
+      board.getOrCreatePlayerByName(user);*/
+    for(int i=1;i<nbPlayernum-nbComputernum;i++)
+    {
+      std::stringstream ss;
+      ss <<"_NonComputerPlayer_"<< i;
+      board.getOrCreatePlayerByName(ss.str());
+    }
+    for(int i=0;i<nbComputernum;i++)
+    {
+      std::stringstream ss;
+      ss <<"Computer"<< i;
+      board.getOrCreatePlayerByName(ss.str());
+    }
+    std::list<std::string> listPlay;
+    for (int i=0;i<board.getNbPlayers();i++)
+    {
+       listPlay.push_back(board.getPlayer(i)->getName());
+    }
+    board.setCases(MapGenerator().generateMap(listPlay,widthnum,heigthnum));
+    MottiRulesManager *rulers= new MottiRulesManager();
+    rulers->setBoard(&board);
+    rulers->initGame();
+    //first user everytime user
+    if(nbPlayernum!=nbComputernum)
+      board.rename(0,user);
+    std::string jsonn=board.generateJson();
+    
+    GamePersistanceService::save(gameid,jsonn);
+    
+    GamePersistanceService::attachUser(gameid,user);
+    delete rulers;
+    
+  } catch (json_parser::ParseError e) {
+    std::cerr << "Oops, the json you gave me does not contain JSON data:" << std::endl;
+    std::cerr << e.what() << std::endl;
+  }
+  
+	return "Game Created";
+      }
+      
+std::string AttachUserOnGame::internalDispatch(std::string msg,std::string session){
+	std::istringstream  ssJson(msg);
+  json_parser::Parser parser(&ssJson);
+  try{
+    json_parser::Value *val = parser.jValue();
+    
+    json_parser::Object* my_object = dynamic_cast<json_parser::Object*>(val);
+    if (my_object==NULL)
+      return "Error casting object";
+    json_parser::Value *id=getValue(my_object,"id");
+    json_parser::Value *user=getValue(my_object,"user");
+    /**
+     * change default name 
+     */
+    std::string gameJson=GamePersistanceService::load(id->cleanStr());
+    Board board(gameJson);
+    //search free user
+    bool found=false;
+    for (int i=0;i<board.getNbPlayers();i++){
+	if (board.getPlayer(i)->getName()==user->cleanStr())
+	{
+	  return "Player is in game";
+	}
+
+    }
+    for (int i=0;i<board.getNbPlayers();i++)
+      if(board.getPlayer(i)->getName().find("_NonComputerPlayer_")!=std::string::npos)
+      {
+	board.rename(i,user->cleanStr());
+	found=true;
+	break;
+      }
+    if (!found)
+	  return "No free player on game";
+    GamePersistanceService::attachUser(id->cleanStr(),user->cleanStr());
+    GamePersistanceService::save(id->cleanStr(),board.generateJson());
+    
+  } catch (json_parser::ParseError e) {
+    std::cerr << "Oops, the json you gave me does not contain JSON data:" << std::endl;
+    std::cerr << e.what() << std::endl;
+  }
+  
+  return "User Attached";
+};
+      
+std::string Play::internalDispatch(std::string msg,std::string session){
+	std::istringstream  ssJson(msg);
+  json_parser::Parser parser(&ssJson);
+  try{
+    json_parser::Value *val = parser.jValue();
+    
+    json_parser::Object* my_object = dynamic_cast<json_parser::Object*>(val);
+    if (my_object==NULL)
+      return "Error casting object";
+    json_parser::Value *id=getValue(my_object,"id");
+    json_parser::Value *strategy=getValue(my_object,"strategy");
+    json_parser::Elements* coordinates=(dynamic_cast<json_parser::Array*>(getValue(my_object,"coordinates")))->elems_;
+    
+    //json_parser::Array *coordinates=(dynamic_cast<json_parser::Array*>(getValue(my_object,"coordinates"));
+    std::list<json_parser::Value *> values=coordinates->values_;
+    /*for (std::list<json_parser::Value *>::iterator it=values.begin(); it != values.end(); ++it)
+    {
+	json_parser::Object* my_object2 = dynamic_cast<json_parser::Object*>(*it);
+	json_parser::Value *x=getValue(my_object2,"X");
+	json_parser::Value *y=getValue(my_object2,"Y");
+    }*/
+    
+    //"{\"id\": \"toto\",\"strategy\": \"Guerilla\",\"coordinates\": [{\"X\":\"1\",\"Y\":\"2\"}, {\"X\":\"1\",\"Y\":\"3\"}]}"
+    std::string user=SessionService::retrieveUserFromSession(session);
+    std::string gameJson=GamePersistanceService::load(id->cleanStr());
+    Board board(gameJson);
+
+    Player *player=board.getPlayerByName(user);
+    if (player==NULL) return "Player not in the game";
+    if (board.getActualPlayer()->getName()!=user)
+      return "Not the turn of the Player";
+    MottiRulesManager *rulers= new MottiRulesManager();
+    rulers->setBoard(&board);
+    
+    if (strategy->cleanStr()=="EndTurn" && board.getActualPlayer()==player)
+      rulers->endTurn();
+    if (strategy->cleanStr()=="EndTurn" && board.getActualPlayer()!=player)
+      return "Player not playing";
+    
+    for (std::list<json_parser::Value *>::iterator it=values.begin(); it != values.end(); ++it)
+    {
+	json_parser::Object* my_object2 = dynamic_cast<json_parser::Object*>(*it);
+	json_parser::Value *x=getValue(my_object2,"X");
+	json_parser::Value *y=getValue(my_object2,"Y");
+	if (strategy->cleanStr()=="Guerilla")
+	  rulers->guerilla(player,atoi(x->cleanStr().c_str()),atoi(y->cleanStr().c_str()));
+	if (strategy->cleanStr()=="Attack")
+	  rulers->attack(player,atoi(x->cleanStr().c_str()),atoi(y->cleanStr().c_str()));
+	if (strategy->cleanStr()=="Defend")
+	  rulers->defend(player,atoi(x->cleanStr().c_str()),atoi(y->cleanStr().c_str()));
+	
+	  
+    }
+    rulers->endTurn();
+    delete rulers;
+    GamePersistanceService::save(id->cleanStr(),board.generateJson());
+    
+    return "Action saved";
+    
+    
+  } catch (json_parser::ParseError e) {
+    std::cerr << "Oops, the json you gave me does not contain JSON data:" << std::endl;
+    std::cerr << e.what() << std::endl;
+  }
+  
+	return "Game Created";
+      };
+/*
+      std::string message=GameDispatcher::dispatch(session3,std::string("play"),std::string("{\"id\": \"toto\",\"strategy\": \"Guerilla\",\"coordinates\": [{\"X\":\"1\",\"Y\":\"2\"}, {\"X\":\"1\",\"Y\":\"3\"}]}"));
+*/
