@@ -1,5 +1,5 @@
 /*  Motti -- a strategy game
-    Copyright (C) 1999-2010 Free Software Foundation
+    Copyright (C) 1999-2014 Free Software Foundation
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
 */
 #include "StdAfx.h"
 #include "Player.h"
+#include <sstream>
+#include"JSONParser.h"
 
 
 Player::Player(std::string name,PLAYERTYPE pp):type_(pp)
@@ -31,7 +33,7 @@ Player::~Player(void)
 }
 
 std::string Player::getName(){
-	return name_;
+    return name_;
 }
 
 std::istream& operator>> (std::istream& in, Player& per){
@@ -97,4 +99,56 @@ bool Player::hasLost(){
 void Player::setLost(bool a){
 	hasLost_=a;
 	}
+	
+std::string Player::generateJson(){
+  std::stringstream in;
+  in <<"{";
+  in <<"\"version\":"<< 1<<",";
+  in <<"\"name\":\""<< name_<<"\",";
+  in <<"\"type\":";
+  switch(type_)
+  {
+    case HUMAN:
+      in <<"\"human\"";
+      break;
+	
+    case COMPUTER:
+      in <<"\"computer\"";
+      break;
+  }
+  in <<",";
+  in <<"\"hasLost\":"<<hasLost_;
+  in <<"}";
+  return in.str();
+}
+
+Player *Player::createFromNode(json_parser::Object* my_object){
+  
+  
+  try{
+    if (my_object==NULL)
+      return NULL;
+    json_parser::Value *version=getValue(my_object,"version");
+    json_parser::Value *name=getValue(my_object,"name");
+    json_parser::Value *type=getValue(my_object,"type");
+    json_parser::Value *hasLost=getValue(my_object,"hasLost");
+    PLAYERTYPE rty=Player::HUMAN;
+    if(type->cleanStr()=="computer")
+      rty=Player::COMPUTER;
+    
+    
+    Player *play=new Player(name->cleanStr(),rty);
+    if (hasLost->cleanStr()=="1")
+      play->setLost(true);
+    else
+      play->setLost(false);
+    
+
+    return play;
+  } catch (json_parser::ParseError e) {
+    std::cerr << "Oops, the json you gave me does not contain JSON data:" << std::endl;
+    std::cerr << e.what() << std::endl;
+  }
+}
+
 	
\ No newline at end of file
